# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import accounts_pb2 as accounts__pb2
import billing_pb2 as billing__pb2
import documentNoStore_pb2 as documentNoStore__pb2
import document_pb2 as document__pb2
import search_pb2 as search__pb2
import strongdoc_pb2 as strongdoc__pb2


class StrongDocServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.RegisterOrganization = channel.unary_unary(
        '/proto.StrongDocService/RegisterOrganization',
        request_serializer=accounts__pb2.RegisterOrganizationRequest.SerializeToString,
        response_deserializer=accounts__pb2.RegisterOrganizationResponse.FromString,
        )
    self.RemoveOrganization = channel.unary_unary(
        '/proto.StrongDocService/RemoveOrganization',
        request_serializer=accounts__pb2.RemoveOrganizationRequest.SerializeToString,
        response_deserializer=accounts__pb2.RemoveOrganizationResponse.FromString,
        )
    self.RegisterUser = channel.unary_unary(
        '/proto.StrongDocService/RegisterUser',
        request_serializer=accounts__pb2.RegisterUserRequest.SerializeToString,
        response_deserializer=accounts__pb2.RegisterUserResponse.FromString,
        )
    self.ListUsers = channel.unary_unary(
        '/proto.StrongDocService/ListUsers',
        request_serializer=accounts__pb2.ListUsersRequest.SerializeToString,
        response_deserializer=accounts__pb2.ListUsersResponse.FromString,
        )
    self.RemoveUser = channel.unary_unary(
        '/proto.StrongDocService/RemoveUser',
        request_serializer=accounts__pb2.RemoveUserRequest.SerializeToString,
        response_deserializer=accounts__pb2.RemoveUserResponse.FromString,
        )
    self.PromoteUser = channel.unary_unary(
        '/proto.StrongDocService/PromoteUser',
        request_serializer=accounts__pb2.PromoteUserRequest.SerializeToString,
        response_deserializer=accounts__pb2.PromoteUserResponse.FromString,
        )
    self.DemoteUser = channel.unary_unary(
        '/proto.StrongDocService/DemoteUser',
        request_serializer=accounts__pb2.DemoteUserRequest.SerializeToString,
        response_deserializer=accounts__pb2.DemoteUserResponse.FromString,
        )
    self.ListDocuments = channel.unary_unary(
        '/proto.StrongDocService/ListDocuments',
        request_serializer=document__pb2.ListDocumentsRequest.SerializeToString,
        response_deserializer=document__pb2.ListDocumentsResponse.FromString,
        )
    self.RemoveDocument = channel.unary_unary(
        '/proto.StrongDocService/RemoveDocument',
        request_serializer=document__pb2.RemoveDocumentRequest.SerializeToString,
        response_deserializer=document__pb2.RemoveDocumentResponse.FromString,
        )
    self.UploadDocumentStream = channel.stream_unary(
        '/proto.StrongDocService/UploadDocumentStream',
        request_serializer=document__pb2.UploadDocStreamReq.SerializeToString,
        response_deserializer=document__pb2.UploadDocStreamResp.FromString,
        )
    self.UploadDocument = channel.unary_unary(
        '/proto.StrongDocService/UploadDocument',
        request_serializer=document__pb2.UploadDocReq.SerializeToString,
        response_deserializer=document__pb2.UploadDocResp.FromString,
        )
    self.DownloadDocumentStream = channel.unary_stream(
        '/proto.StrongDocService/DownloadDocumentStream',
        request_serializer=document__pb2.DownloadDocStreamReq.SerializeToString,
        response_deserializer=document__pb2.DownloadDocStreamResp.FromString,
        )
    self.DownloadDocument = channel.unary_unary(
        '/proto.StrongDocService/DownloadDocument',
        request_serializer=document__pb2.DownloadDocReq.SerializeToString,
        response_deserializer=document__pb2.DownloadDocResp.FromString,
        )
    self.EncryptDocumentStream = channel.stream_stream(
        '/proto.StrongDocService/EncryptDocumentStream',
        request_serializer=documentNoStore__pb2.EncryptDocStreamReq.SerializeToString,
        response_deserializer=documentNoStore__pb2.EncryptDocStreamResp.FromString,
        )
    self.EncryptDocument = channel.unary_unary(
        '/proto.StrongDocService/EncryptDocument',
        request_serializer=documentNoStore__pb2.EncryptDocReq.SerializeToString,
        response_deserializer=documentNoStore__pb2.EncryptDocResp.FromString,
        )
    self.DecryptDocumentStream = channel.stream_stream(
        '/proto.StrongDocService/DecryptDocumentStream',
        request_serializer=documentNoStore__pb2.DecryptDocStreamReq.SerializeToString,
        response_deserializer=documentNoStore__pb2.DecryptDocStreamResp.FromString,
        )
    self.DecryptDocument = channel.unary_unary(
        '/proto.StrongDocService/DecryptDocument',
        request_serializer=documentNoStore__pb2.DecryptDocReq.SerializeToString,
        response_deserializer=documentNoStore__pb2.DecryptDocResp.FromString,
        )
    self.ShareDocument = channel.unary_unary(
        '/proto.StrongDocService/ShareDocument',
        request_serializer=document__pb2.ShareDocumentRequest.SerializeToString,
        response_deserializer=document__pb2.ShareDocumentResponse.FromString,
        )
    self.UnshareDocument = channel.unary_unary(
        '/proto.StrongDocService/UnshareDocument',
        request_serializer=document__pb2.UnshareDocumentRequest.SerializeToString,
        response_deserializer=document__pb2.UnshareDocumentResponse.FromString,
        )
    self.Login = channel.unary_unary(
        '/proto.StrongDocService/Login',
        request_serializer=accounts__pb2.LoginRequest.SerializeToString,
        response_deserializer=accounts__pb2.LoginResponse.FromString,
        )
    self.Logout = channel.unary_unary(
        '/proto.StrongDocService/Logout',
        request_serializer=accounts__pb2.LogoutRequest.SerializeToString,
        response_deserializer=accounts__pb2.LogoutResponse.FromString,
        )
    self.Search = channel.unary_unary(
        '/proto.StrongDocService/Search',
        request_serializer=search__pb2.SearchRequest.SerializeToString,
        response_deserializer=search__pb2.SearchResponse.FromString,
        )
    self.AddSharableOrg = channel.unary_unary(
        '/proto.StrongDocService/AddSharableOrg',
        request_serializer=accounts__pb2.AddSharableOrgRequest.SerializeToString,
        response_deserializer=accounts__pb2.AddSharableOrgResponse.FromString,
        )
    self.RemoveSharableOrg = channel.unary_unary(
        '/proto.StrongDocService/RemoveSharableOrg',
        request_serializer=accounts__pb2.RemoveSharableOrgRequest.SerializeToString,
        response_deserializer=accounts__pb2.RemoveSharableOrgResponse.FromString,
        )
    self.SetMultiLevelSharing = channel.unary_unary(
        '/proto.StrongDocService/SetMultiLevelSharing',
        request_serializer=accounts__pb2.SetMultiLevelSharingRequest.SerializeToString,
        response_deserializer=accounts__pb2.SetMultiLevelSharingResponse.FromString,
        )
    self.GetBillingDetails = channel.unary_unary(
        '/proto.StrongDocService/GetBillingDetails',
        request_serializer=billing__pb2.GetBillingDetailsReq.SerializeToString,
        response_deserializer=billing__pb2.GetBillingDetailsResp.FromString,
        )
    self.GetBillingFrequencyList = channel.unary_unary(
        '/proto.StrongDocService/GetBillingFrequencyList',
        request_serializer=billing__pb2.GetBillingFrequencyListReq.SerializeToString,
        response_deserializer=billing__pb2.GetBillingFrequencyListResp.FromString,
        )
    self.SetNextBillingFrequency = channel.unary_unary(
        '/proto.StrongDocService/SetNextBillingFrequency',
        request_serializer=billing__pb2.SetNextBillingFrequencyReq.SerializeToString,
        response_deserializer=billing__pb2.SetNextBillingFrequencyResp.FromString,
        )
    self.GetConfiguration = channel.unary_unary(
        '/proto.StrongDocService/GetConfiguration',
        request_serializer=strongdoc__pb2.GetConfigurationReq.SerializeToString,
        response_deserializer=strongdoc__pb2.GetConfigurationResp.FromString,
        )
    self.ProcessSubscriptionEvent = channel.unary_unary(
        '/proto.StrongDocService/ProcessSubscriptionEvent',
        request_serializer=billing__pb2.ProcessSubscriptionEventReq.SerializeToString,
        response_deserializer=billing__pb2.ProcessSubscriptionEventResp.FromString,
        )


class StrongDocServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def RegisterOrganization(self, request, context):
    """Registers a new organization

    The user who created the organization is automatically an administrator

    Does not require Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveOrganization(self, request, context):
    """Remove an organization and its search indexes

    Requires Administrator privilege. Only an administrator can remove the whole organization

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterUser(self, request, context):
    """Register new user

    Creates new user if it doesn't already exist. If the user already exist, and
    error is thrown

    Requires administrator privilege
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListUsers(self, request, context):
    """rpc GetUserInfo(GetUserInfoRequest) returns (GetUserInfoResponse) {
    option (google.api.http) = {
    post: "/v1/account/getuserinfo"
    body: "*"
    };
    option (grpc.gateway.protoc_gen_swagger.options.openapiv2_operation) = {
    security: {
    security_requirement: {
    key: "ApiKeyAuth";
    value: {};
    }
    };
    };
    }

    List the users of the organization

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveUser(self, request, context):
    """Remove user from organization

    Removes the user from the organization. The users documents still exists, 
    but belong to the organization, only accessible by organization admin.

    Requires administrator privilege.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PromoteUser(self, request, context):
    """Promote a regular user to administrator at the organization

    Requires administrator privilege.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DemoteUser(self, request, context):
    """Demote administrator to regular user at the organization. Attempting to
    demote the last administrator of an organization will fail

    Requires administrator privilege.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDocuments(self, request, context):
    """List the documents the user can access

    Administrators can see all documents belonging to the organization

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveDocument(self, request, context):
    """Remove document the user can access

    Admin user can remove document for the whole organization
    Regular user only can remove document for him/herself

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UploadDocumentStream(self, request_iterator, context):
    """Upload document

    User can upload document to the organization for storage

    Requires Login 
    This is not available through gRPC REST gateway, 
    since REST api does not support streaming protocol
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UploadDocument(self, request, context):
    """Upload document

    User can upload document to the organization for storage

    Requires Login 
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DownloadDocumentStream(self, request, context):
    """Download document stream

    User can download the documents

    Requires Login 
    This is not available through gRPC REST gateway, 
    since REST api does not support streaming protocol
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DownloadDocument(self, request, context):
    """Download document

    User can download the documents

    Requires Login 
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EncryptDocumentStream(self, request_iterator, context):
    """Encrypt document stream encrypts the document and returns the ciphertext
    back to the user without storing it.

    Requires Login 
    This is not available through gRPC REST gateway, 
    since REST api does not support streaming protocol
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EncryptDocument(self, request, context):
    """Encrypt document encrypts the document and returns the ciphertext
    back to the user without storing it.

    Requires Login 
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DecryptDocumentStream(self, request_iterator, context):
    """Decrypt document stream decrypts the ciphertext passed in and returns 
    decrypted plain text back to the user without storing it

    Requires Login 
    This is not available through gRPC REST gateway, 
    since REST api does not support streaming protocol
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DecryptDocument(self, request, context):
    """Decrypt document decrypts the ciphertext passed in and returns 
    decrypted plain text back to the user without storing it
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ShareDocument(self, request, context):
    """Share a document to another user

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnshareDocument(self, request, context):
    """Unshare a document that had previously been shared to a user

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Login(self, request, context):
    """Obtain an authentication token to be used with other APIs

    An authentication token will be returned after user has been validated
    The returned token will be used as a Bearer Token and need to be set in 
    the request header
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Logout(self, request, context):
    """Logout current user

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Search(self, request, context):
    """Search within a list of user's accessible documents

    The response will include a list document id and its score when matches are found

    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddSharableOrg(self, request, context):
    """Add a sharable organization to the user's organization.

    Requires Administrator privilege.
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveSharableOrg(self, request, context):
    """Remove a sharable organization from the user's organization.

    Requires Administrator privilege.
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetMultiLevelSharing(self, request, context):
    """Update the organization's multi-level sharing setting

    Requires Administrator privilege.
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetBillingDetails(self, request, context):
    """List all items of the cost breakdown and also other details such as the billing frequency

    Requires Administrator privilege
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetBillingFrequencyList(self, request, context):
    """Obtain the list of billing frequencies (past, current and future)

    Requires Administrator privilege
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetNextBillingFrequency(self, request, context):
    """Change the next billing frequency

    Requires Administrator privilege
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConfiguration(self, request, context):
    """Show current server configuration

    Requires Administrator privilege. Only an administrator can see server configuration
    Requires Login
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ProcessSubscriptionEvent(self, request, context):
    """Process subscription-related event

    Designed to be called only by third-party services (like online payments provider)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StrongDocServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'RegisterOrganization': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterOrganization,
          request_deserializer=accounts__pb2.RegisterOrganizationRequest.FromString,
          response_serializer=accounts__pb2.RegisterOrganizationResponse.SerializeToString,
      ),
      'RemoveOrganization': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveOrganization,
          request_deserializer=accounts__pb2.RemoveOrganizationRequest.FromString,
          response_serializer=accounts__pb2.RemoveOrganizationResponse.SerializeToString,
      ),
      'RegisterUser': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterUser,
          request_deserializer=accounts__pb2.RegisterUserRequest.FromString,
          response_serializer=accounts__pb2.RegisterUserResponse.SerializeToString,
      ),
      'ListUsers': grpc.unary_unary_rpc_method_handler(
          servicer.ListUsers,
          request_deserializer=accounts__pb2.ListUsersRequest.FromString,
          response_serializer=accounts__pb2.ListUsersResponse.SerializeToString,
      ),
      'RemoveUser': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveUser,
          request_deserializer=accounts__pb2.RemoveUserRequest.FromString,
          response_serializer=accounts__pb2.RemoveUserResponse.SerializeToString,
      ),
      'PromoteUser': grpc.unary_unary_rpc_method_handler(
          servicer.PromoteUser,
          request_deserializer=accounts__pb2.PromoteUserRequest.FromString,
          response_serializer=accounts__pb2.PromoteUserResponse.SerializeToString,
      ),
      'DemoteUser': grpc.unary_unary_rpc_method_handler(
          servicer.DemoteUser,
          request_deserializer=accounts__pb2.DemoteUserRequest.FromString,
          response_serializer=accounts__pb2.DemoteUserResponse.SerializeToString,
      ),
      'ListDocuments': grpc.unary_unary_rpc_method_handler(
          servicer.ListDocuments,
          request_deserializer=document__pb2.ListDocumentsRequest.FromString,
          response_serializer=document__pb2.ListDocumentsResponse.SerializeToString,
      ),
      'RemoveDocument': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveDocument,
          request_deserializer=document__pb2.RemoveDocumentRequest.FromString,
          response_serializer=document__pb2.RemoveDocumentResponse.SerializeToString,
      ),
      'UploadDocumentStream': grpc.stream_unary_rpc_method_handler(
          servicer.UploadDocumentStream,
          request_deserializer=document__pb2.UploadDocStreamReq.FromString,
          response_serializer=document__pb2.UploadDocStreamResp.SerializeToString,
      ),
      'UploadDocument': grpc.unary_unary_rpc_method_handler(
          servicer.UploadDocument,
          request_deserializer=document__pb2.UploadDocReq.FromString,
          response_serializer=document__pb2.UploadDocResp.SerializeToString,
      ),
      'DownloadDocumentStream': grpc.unary_stream_rpc_method_handler(
          servicer.DownloadDocumentStream,
          request_deserializer=document__pb2.DownloadDocStreamReq.FromString,
          response_serializer=document__pb2.DownloadDocStreamResp.SerializeToString,
      ),
      'DownloadDocument': grpc.unary_unary_rpc_method_handler(
          servicer.DownloadDocument,
          request_deserializer=document__pb2.DownloadDocReq.FromString,
          response_serializer=document__pb2.DownloadDocResp.SerializeToString,
      ),
      'EncryptDocumentStream': grpc.stream_stream_rpc_method_handler(
          servicer.EncryptDocumentStream,
          request_deserializer=documentNoStore__pb2.EncryptDocStreamReq.FromString,
          response_serializer=documentNoStore__pb2.EncryptDocStreamResp.SerializeToString,
      ),
      'EncryptDocument': grpc.unary_unary_rpc_method_handler(
          servicer.EncryptDocument,
          request_deserializer=documentNoStore__pb2.EncryptDocReq.FromString,
          response_serializer=documentNoStore__pb2.EncryptDocResp.SerializeToString,
      ),
      'DecryptDocumentStream': grpc.stream_stream_rpc_method_handler(
          servicer.DecryptDocumentStream,
          request_deserializer=documentNoStore__pb2.DecryptDocStreamReq.FromString,
          response_serializer=documentNoStore__pb2.DecryptDocStreamResp.SerializeToString,
      ),
      'DecryptDocument': grpc.unary_unary_rpc_method_handler(
          servicer.DecryptDocument,
          request_deserializer=documentNoStore__pb2.DecryptDocReq.FromString,
          response_serializer=documentNoStore__pb2.DecryptDocResp.SerializeToString,
      ),
      'ShareDocument': grpc.unary_unary_rpc_method_handler(
          servicer.ShareDocument,
          request_deserializer=document__pb2.ShareDocumentRequest.FromString,
          response_serializer=document__pb2.ShareDocumentResponse.SerializeToString,
      ),
      'UnshareDocument': grpc.unary_unary_rpc_method_handler(
          servicer.UnshareDocument,
          request_deserializer=document__pb2.UnshareDocumentRequest.FromString,
          response_serializer=document__pb2.UnshareDocumentResponse.SerializeToString,
      ),
      'Login': grpc.unary_unary_rpc_method_handler(
          servicer.Login,
          request_deserializer=accounts__pb2.LoginRequest.FromString,
          response_serializer=accounts__pb2.LoginResponse.SerializeToString,
      ),
      'Logout': grpc.unary_unary_rpc_method_handler(
          servicer.Logout,
          request_deserializer=accounts__pb2.LogoutRequest.FromString,
          response_serializer=accounts__pb2.LogoutResponse.SerializeToString,
      ),
      'Search': grpc.unary_unary_rpc_method_handler(
          servicer.Search,
          request_deserializer=search__pb2.SearchRequest.FromString,
          response_serializer=search__pb2.SearchResponse.SerializeToString,
      ),
      'AddSharableOrg': grpc.unary_unary_rpc_method_handler(
          servicer.AddSharableOrg,
          request_deserializer=accounts__pb2.AddSharableOrgRequest.FromString,
          response_serializer=accounts__pb2.AddSharableOrgResponse.SerializeToString,
      ),
      'RemoveSharableOrg': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveSharableOrg,
          request_deserializer=accounts__pb2.RemoveSharableOrgRequest.FromString,
          response_serializer=accounts__pb2.RemoveSharableOrgResponse.SerializeToString,
      ),
      'SetMultiLevelSharing': grpc.unary_unary_rpc_method_handler(
          servicer.SetMultiLevelSharing,
          request_deserializer=accounts__pb2.SetMultiLevelSharingRequest.FromString,
          response_serializer=accounts__pb2.SetMultiLevelSharingResponse.SerializeToString,
      ),
      'GetBillingDetails': grpc.unary_unary_rpc_method_handler(
          servicer.GetBillingDetails,
          request_deserializer=billing__pb2.GetBillingDetailsReq.FromString,
          response_serializer=billing__pb2.GetBillingDetailsResp.SerializeToString,
      ),
      'GetBillingFrequencyList': grpc.unary_unary_rpc_method_handler(
          servicer.GetBillingFrequencyList,
          request_deserializer=billing__pb2.GetBillingFrequencyListReq.FromString,
          response_serializer=billing__pb2.GetBillingFrequencyListResp.SerializeToString,
      ),
      'SetNextBillingFrequency': grpc.unary_unary_rpc_method_handler(
          servicer.SetNextBillingFrequency,
          request_deserializer=billing__pb2.SetNextBillingFrequencyReq.FromString,
          response_serializer=billing__pb2.SetNextBillingFrequencyResp.SerializeToString,
      ),
      'GetConfiguration': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfiguration,
          request_deserializer=strongdoc__pb2.GetConfigurationReq.FromString,
          response_serializer=strongdoc__pb2.GetConfigurationResp.SerializeToString,
      ),
      'ProcessSubscriptionEvent': grpc.unary_unary_rpc_method_handler(
          servicer.ProcessSubscriptionEvent,
          request_deserializer=billing__pb2.ProcessSubscriptionEventReq.FromString,
          response_serializer=billing__pb2.ProcessSubscriptionEventResp.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.StrongDocService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: document.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='document.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\tDocuments\210\001\001',
  serialized_pb=b'\n\x0e\x64ocument.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"J\n\x12UploadDocStreamReq\x12\x11\n\x07\x64ocName\x18\x01 \x01(\tH\x00\x12\x13\n\tplaintext\x18\x02 \x01(\x0cH\x00\x42\x0c\n\nNameOrData\"3\n\x13UploadDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\"%\n\x14\x44ownloadDocStreamReq\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\"9\n\x15\x44ownloadDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"\x8c\x01\n\x0cUploadDocReq\x12\x0f\n\x07\x64ocName\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:X\x92\x41U\n\x0e*\x0cUploadDocReq2C\x12\x41{\"docName\": \"bribeamount\", \"plaintext\": \"I paid 1M to Volodymyr\"}\"S\n\rUploadDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t:3\x92\x41\x30\n\x0f*\rUploadDocResp2\x1d\x12\x1b{\"docID\": \"bribeamount_ID\"}\"U\n\x0e\x44ownloadDocReq\x12\r\n\x05\x64ocID\x18\x01 \x01(\t:4\x92\x41\x31\n\x10*\x0e\x44ownloadDocReq2\x1d\x12\x1b{\"docID\": \"bribeamount_ID\"}\"\x90\x01\n\x0f\x44ownloadDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:[\x92\x41X\n\x10*\x0e\x44ownloadDocReq2D\x12\x42{\"docID\": \"bribeamount_ID\", \"plaintext\": \"I paid 1M to Volodymyr\"}\"\x82\x01\n\x14ShareDocumentRequest\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t:K\x92\x41H\n\x16*\x14ShareDocumentRequest2.\x12,{\"docID\": \"bribeamount_ID\", \"userID\": \"FBI\"}\"[\n\x15ShareDocumentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:1\x92\x41.\n\x17*\x15ShareDocumentResponse2\x13\x12\x11{\"success\": true}\"\x8b\x01\n\x16UnshareDocumentRequest\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t:R\x92\x41O\n\x18*\x16UnshareDocumentRequest23\x12\x31{\"docID\": \"bribeamount_ID\", \"userID\": \"Fox News\"}\"X\n\x17UnshareDocumentResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03:.\x92\x41+\n\x19*\x17UnshareDocumentResponse2\x0e\x12\x0c{\"count\": 1}\"3\n\x14ListDocumentsRequest:\x1b\x92\x41\x18\n\x16*\x14ListDocumentsRequest\"\x84\x02\n\x15ListDocumentsResponse\x12\x38\n\tdocuments\x18\x01 \x03(\x0b\x32%.proto.ListDocumentsResponse.Document\x1a\x38\n\x08\x44ocument\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x0f\n\x07\x64ocName\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x04:w\x92\x41t\n\x17*\x15ListDocumentsResponse2Y\x12W{\"documents\": [{\"docID\": \"bribeamount_ID\", \"docName\": \"bribeamount.pdf\", \"size\": 561}]}\"c\n\x15RemoveDocumentRequest\x12\r\n\x05\x64ocID\x18\x01 \x01(\t:;\x92\x41\x38\n\x17*\x15RemoveDocumentRequest2\x1d\x12\x1b{\"docID\": \"bribeamount_ID\"}\"[\n\x16RemoveDocumentResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08:1\x92\x41.\n\x18*\x16RemoveDocumentResponse2\x12\x12\x10{\"status\": true}B2\n\"com.strongsalt.strongdoc.sdk.protoB\tDocuments\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_UPLOADDOCSTREAMREQ = _descriptor.Descriptor(
  name='UploadDocStreamReq',
  full_name='proto.UploadDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.UploadDocStreamReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.UploadDocStreamReq.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='NameOrData', full_name='proto.UploadDocStreamReq.NameOrData',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=71,
  serialized_end=145,
)


_UPLOADDOCSTREAMRESP = _descriptor.Descriptor(
  name='UploadDocStreamResp',
  full_name='proto.UploadDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.UploadDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='proto.UploadDocStreamResp.bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=198,
)


_DOWNLOADDOCSTREAMREQ = _descriptor.Descriptor(
  name='DownloadDocStreamReq',
  full_name='proto.DownloadDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocStreamReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=237,
)


_DOWNLOADDOCSTREAMRESP = _descriptor.Descriptor(
  name='DownloadDocStreamResp',
  full_name='proto.DownloadDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DownloadDocStreamResp.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=296,
)


_UPLOADDOCREQ = _descriptor.Descriptor(
  name='UploadDocReq',
  full_name='proto.UploadDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.UploadDocReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.UploadDocReq.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AU\n\016*\014UploadDocReq2C\022A{\"docName\": \"bribeamount\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=439,
)


_UPLOADDOCRESP = _descriptor.Descriptor(
  name='UploadDocResp',
  full_name='proto.UploadDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.UploadDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A0\n\017*\rUploadDocResp2\035\022\033{\"docID\": \"bribeamount_ID\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=524,
)


_DOWNLOADDOCREQ = _descriptor.Descriptor(
  name='DownloadDocReq',
  full_name='proto.DownloadDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A1\n\020*\016DownloadDocReq2\035\022\033{\"docID\": \"bribeamount_ID\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=611,
)


_DOWNLOADDOCRESP = _descriptor.Descriptor(
  name='DownloadDocResp',
  full_name='proto.DownloadDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DownloadDocResp.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AX\n\020*\016DownloadDocReq2D\022B{\"docID\": \"bribeamount_ID\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=758,
)


_SHAREDOCUMENTREQUEST = _descriptor.Descriptor(
  name='ShareDocumentRequest',
  full_name='proto.ShareDocumentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.ShareDocumentRequest.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.ShareDocumentRequest.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AH\n\026*\024ShareDocumentRequest2.\022,{\"docID\": \"bribeamount_ID\", \"userID\": \"FBI\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=891,
)


_SHAREDOCUMENTRESPONSE = _descriptor.Descriptor(
  name='ShareDocumentResponse',
  full_name='proto.ShareDocumentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.ShareDocumentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A.\n\027*\025ShareDocumentResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=984,
)


_UNSHAREDOCUMENTREQUEST = _descriptor.Descriptor(
  name='UnshareDocumentRequest',
  full_name='proto.UnshareDocumentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.UnshareDocumentRequest.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.UnshareDocumentRequest.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AO\n\030*\026UnshareDocumentRequest23\0221{\"docID\": \"bribeamount_ID\", \"userID\": \"Fox News\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1126,
)


_UNSHAREDOCUMENTRESPONSE = _descriptor.Descriptor(
  name='UnshareDocumentResponse',
  full_name='proto.UnshareDocumentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='proto.UnshareDocumentResponse.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\031*\027UnshareDocumentResponse2\016\022\014{\"count\": 1}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1216,
)


_LISTDOCUMENTSREQUEST = _descriptor.Descriptor(
  name='ListDocumentsRequest',
  full_name='proto.ListDocumentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\030\n\026*\024ListDocumentsRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1269,
)


_LISTDOCUMENTSRESPONSE_DOCUMENT = _descriptor.Descriptor(
  name='Document',
  full_name='proto.ListDocumentsResponse.Document',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.ListDocumentsResponse.Document.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.ListDocumentsResponse.Document.docName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.ListDocumentsResponse.Document.size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1411,
)

_LISTDOCUMENTSRESPONSE = _descriptor.Descriptor(
  name='ListDocumentsResponse',
  full_name='proto.ListDocumentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='documents', full_name='proto.ListDocumentsResponse.documents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTDOCUMENTSRESPONSE_DOCUMENT, ],
  enum_types=[
  ],
  serialized_options=b'\222At\n\027*\025ListDocumentsResponse2Y\022W{\"documents\": [{\"docID\": \"bribeamount_ID\", \"docName\": \"bribeamount.pdf\", \"size\": 561}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1532,
)


_REMOVEDOCUMENTREQUEST = _descriptor.Descriptor(
  name='RemoveDocumentRequest',
  full_name='proto.RemoveDocumentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.RemoveDocumentRequest.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A8\n\027*\025RemoveDocumentRequest2\035\022\033{\"docID\": \"bribeamount_ID\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=1633,
)


_REMOVEDOCUMENTRESPONSE = _descriptor.Descriptor(
  name='RemoveDocumentResponse',
  full_name='proto.RemoveDocumentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RemoveDocumentResponse.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A.\n\030*\026RemoveDocumentResponse2\022\022\020{\"status\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1635,
  serialized_end=1726,
)

_UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _UPLOADDOCSTREAMREQ.fields_by_name['docName'])
_UPLOADDOCSTREAMREQ.fields_by_name['docName'].containing_oneof = _UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData']
_UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _UPLOADDOCSTREAMREQ.fields_by_name['plaintext'])
_UPLOADDOCSTREAMREQ.fields_by_name['plaintext'].containing_oneof = _UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData']
_LISTDOCUMENTSRESPONSE_DOCUMENT.containing_type = _LISTDOCUMENTSRESPONSE
_LISTDOCUMENTSRESPONSE.fields_by_name['documents'].message_type = _LISTDOCUMENTSRESPONSE_DOCUMENT
DESCRIPTOR.message_types_by_name['UploadDocStreamReq'] = _UPLOADDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['UploadDocStreamResp'] = _UPLOADDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['DownloadDocStreamReq'] = _DOWNLOADDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['DownloadDocStreamResp'] = _DOWNLOADDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['UploadDocReq'] = _UPLOADDOCREQ
DESCRIPTOR.message_types_by_name['UploadDocResp'] = _UPLOADDOCRESP
DESCRIPTOR.message_types_by_name['DownloadDocReq'] = _DOWNLOADDOCREQ
DESCRIPTOR.message_types_by_name['DownloadDocResp'] = _DOWNLOADDOCRESP
DESCRIPTOR.message_types_by_name['ShareDocumentRequest'] = _SHAREDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name['ShareDocumentResponse'] = _SHAREDOCUMENTRESPONSE
DESCRIPTOR.message_types_by_name['UnshareDocumentRequest'] = _UNSHAREDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name['UnshareDocumentResponse'] = _UNSHAREDOCUMENTRESPONSE
DESCRIPTOR.message_types_by_name['ListDocumentsRequest'] = _LISTDOCUMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListDocumentsResponse'] = _LISTDOCUMENTSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveDocumentRequest'] = _REMOVEDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name['RemoveDocumentResponse'] = _REMOVEDOCUMENTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadDocStreamReq = _reflection.GeneratedProtocolMessageType('UploadDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCSTREAMREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocStreamReq)
  })
_sym_db.RegisterMessage(UploadDocStreamReq)

UploadDocStreamResp = _reflection.GeneratedProtocolMessageType('UploadDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCSTREAMRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocStreamResp)
  })
_sym_db.RegisterMessage(UploadDocStreamResp)

DownloadDocStreamReq = _reflection.GeneratedProtocolMessageType('DownloadDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCSTREAMREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocStreamReq)
  })
_sym_db.RegisterMessage(DownloadDocStreamReq)

DownloadDocStreamResp = _reflection.GeneratedProtocolMessageType('DownloadDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCSTREAMRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocStreamResp)
  })
_sym_db.RegisterMessage(DownloadDocStreamResp)

UploadDocReq = _reflection.GeneratedProtocolMessageType('UploadDocReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocReq)
  })
_sym_db.RegisterMessage(UploadDocReq)

UploadDocResp = _reflection.GeneratedProtocolMessageType('UploadDocResp', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocResp)
  })
_sym_db.RegisterMessage(UploadDocResp)

DownloadDocReq = _reflection.GeneratedProtocolMessageType('DownloadDocReq', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocReq)
  })
_sym_db.RegisterMessage(DownloadDocReq)

DownloadDocResp = _reflection.GeneratedProtocolMessageType('DownloadDocResp', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocResp)
  })
_sym_db.RegisterMessage(DownloadDocResp)

ShareDocumentRequest = _reflection.GeneratedProtocolMessageType('ShareDocumentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDOCUMENTREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ShareDocumentRequest)
  })
_sym_db.RegisterMessage(ShareDocumentRequest)

ShareDocumentResponse = _reflection.GeneratedProtocolMessageType('ShareDocumentResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDOCUMENTRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ShareDocumentResponse)
  })
_sym_db.RegisterMessage(ShareDocumentResponse)

UnshareDocumentRequest = _reflection.GeneratedProtocolMessageType('UnshareDocumentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNSHAREDOCUMENTREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UnshareDocumentRequest)
  })
_sym_db.RegisterMessage(UnshareDocumentRequest)

UnshareDocumentResponse = _reflection.GeneratedProtocolMessageType('UnshareDocumentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNSHAREDOCUMENTRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UnshareDocumentResponse)
  })
_sym_db.RegisterMessage(UnshareDocumentResponse)

ListDocumentsRequest = _reflection.GeneratedProtocolMessageType('ListDocumentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDOCUMENTSREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListDocumentsRequest)
  })
_sym_db.RegisterMessage(ListDocumentsRequest)

ListDocumentsResponse = _reflection.GeneratedProtocolMessageType('ListDocumentsResponse', (_message.Message,), {

  'Document' : _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
    'DESCRIPTOR' : _LISTDOCUMENTSRESPONSE_DOCUMENT,
    '__module__' : 'document_pb2'
    # @@protoc_insertion_point(class_scope:proto.ListDocumentsResponse.Document)
    })
  ,
  'DESCRIPTOR' : _LISTDOCUMENTSRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListDocumentsResponse)
  })
_sym_db.RegisterMessage(ListDocumentsResponse)
_sym_db.RegisterMessage(ListDocumentsResponse.Document)

RemoveDocumentRequest = _reflection.GeneratedProtocolMessageType('RemoveDocumentRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDOCUMENTREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveDocumentRequest)
  })
_sym_db.RegisterMessage(RemoveDocumentRequest)

RemoveDocumentResponse = _reflection.GeneratedProtocolMessageType('RemoveDocumentResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDOCUMENTRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveDocumentResponse)
  })
_sym_db.RegisterMessage(RemoveDocumentResponse)


DESCRIPTOR._options = None
_UPLOADDOCREQ._options = None
_UPLOADDOCRESP._options = None
_DOWNLOADDOCREQ._options = None
_DOWNLOADDOCRESP._options = None
_SHAREDOCUMENTREQUEST._options = None
_SHAREDOCUMENTRESPONSE._options = None
_UNSHAREDOCUMENTREQUEST._options = None
_UNSHAREDOCUMENTRESPONSE._options = None
_LISTDOCUMENTSREQUEST._options = None
_LISTDOCUMENTSRESPONSE._options = None
_REMOVEDOCUMENTREQUEST._options = None
_REMOVEDOCUMENTRESPONSE._options = None
# @@protoc_insertion_point(module_scope)



from strongdoc import client
from strongdoc import constants
from strongdoc.proto import accounts_pb2, strongdoc_pb2_grpc


def login(userid, password, orgid):
    """
    Verify the user and organization identity, and returns a JWT token for future API use.
    A gRPC connection timeout will be implemented.

    :param userid:
       The login user ID
    :type userid:
        `string`
    :param password:
       The ogin user password
    :type password:
        `string`
    :param orgid:
       The login organization ID
    :type orgid:
        `string`
    :raises grpc.RpcError:
        Raised by the gRPC library to indicate non-OK-status RPC termination.

    :returns:
        The JWT token used to authenticate user/org when using StrongDoc APIs.
    :rtype:
        `string`
    """
    with client.connect_to_server_with_no_auth() as no_auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(no_auth_conn)

        # create login request message
        request = accounts_pb2.LoginRequest(userID=userid, password=password, orgID=orgid)

        # make the call
        response = client_stub.Login(request, timeout=constants.GRPC_TIMEOUT)

        return response.token



import setuptools

with open('HISTORY.rst') as history_file:
    history = history_file.read()

with open("README.md", "r") as fh:
    long_description = fh.read() + history

setuptools.setup(
    name="strongsalt-strongdoc-python-sdk",
    version="0.0.2",
    author="StrongDoc",
    author_email="info@strongsalt.com",
    description="The StrongDoc Python SDK for interacting with the StrongDoc API.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/overnest/strongdoc-python-sdk",
    license="LICENSE.txt",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=[
        "grpcio",
        "protobuf",
        "six"
    ],
    classifiers=[
        "Operating System :: OS Independent",
        "Topic :: Security",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS :: MacOS X",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: documentNoStore.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='documentNoStore.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\020DocumentsNoStore\210\001\001',
  serialized_pb=b'\n\x15\x64ocumentNoStore.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"K\n\x13\x45ncryptDocStreamReq\x12\x11\n\x07\x64ocName\x18\x01 \x01(\tH\x00\x12\x13\n\tplaintext\x18\x02 \x01(\x0cH\x00\x42\x0c\n\nNameOrData\"9\n\x14\x45ncryptDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\x0c\"H\n\x13\x44\x65\x63ryptDocStreamReq\x12\x0f\n\x05\x64ocID\x18\x01 \x01(\tH\x00\x12\x14\n\nciphertext\x18\x02 \x01(\x0cH\x00\x42\n\n\x08IdOrData\"8\n\x14\x44\x65\x63ryptDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"\x92\x01\n\rEncryptDocReq\x12\x0f\n\x07\x64ocName\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:]\x92\x41Z\n\x0f*\rEncryptDocReq2G\x12\x45{\"docName\": \"bribeamount.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}\"\x93\x01\n\x0e\x45ncryptDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\t:^\x92\x41[\n\x10*\x0e\x45ncryptDocResp2G\x12\x45{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}\"\x91\x01\n\rDecryptDocReq\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\t:]\x92\x41Z\n\x0f*\rDecryptDocReq2G\x12\x45{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}\"\x93\x01\n\x0e\x44\x65\x63ryptDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:_\x92\x41\\\n\x10*\x0e\x44\x65\x63ryptDocResp2H\x12\x46{\"docID\": \"bribeamount_ID.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}B9\n\"com.strongsalt.strongdoc.sdk.protoB\x10\x44ocumentsNoStore\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_ENCRYPTDOCSTREAMREQ = _descriptor.Descriptor(
  name='EncryptDocStreamReq',
  full_name='proto.EncryptDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.EncryptDocStreamReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.EncryptDocStreamReq.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='NameOrData', full_name='proto.EncryptDocStreamReq.NameOrData',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=78,
  serialized_end=153,
)


_ENCRYPTDOCSTREAMRESP = _descriptor.Descriptor(
  name='EncryptDocStreamResp',
  full_name='proto.EncryptDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.EncryptDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.EncryptDocStreamResp.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=212,
)


_DECRYPTDOCSTREAMREQ = _descriptor.Descriptor(
  name='DecryptDocStreamReq',
  full_name='proto.DecryptDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocStreamReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.DecryptDocStreamReq.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='IdOrData', full_name='proto.DecryptDocStreamReq.IdOrData',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=214,
  serialized_end=286,
)


_DECRYPTDOCSTREAMRESP = _descriptor.Descriptor(
  name='DecryptDocStreamResp',
  full_name='proto.DecryptDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DecryptDocStreamResp.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=344,
)


_ENCRYPTDOCREQ = _descriptor.Descriptor(
  name='EncryptDocReq',
  full_name='proto.EncryptDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.EncryptDocReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.EncryptDocReq.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AZ\n\017*\rEncryptDocReq2G\022E{\"docName\": \"bribeamount.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=493,
)


_ENCRYPTDOCRESP = _descriptor.Descriptor(
  name='EncryptDocResp',
  full_name='proto.EncryptDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.EncryptDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.EncryptDocResp.ciphertext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A[\n\020*\016EncryptDocResp2G\022E{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=643,
)


_DECRYPTDOCREQ = _descriptor.Descriptor(
  name='DecryptDocReq',
  full_name='proto.DecryptDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.DecryptDocReq.ciphertext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AZ\n\017*\rDecryptDocReq2G\022E{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=791,
)


_DECRYPTDOCRESP = _descriptor.Descriptor(
  name='DecryptDocResp',
  full_name='proto.DecryptDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DecryptDocResp.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\\\n\020*\016DecryptDocResp2H\022F{\"docID\": \"bribeamount_ID.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=941,
)

_ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _ENCRYPTDOCSTREAMREQ.fields_by_name['docName'])
_ENCRYPTDOCSTREAMREQ.fields_by_name['docName'].containing_oneof = _ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData']
_ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _ENCRYPTDOCSTREAMREQ.fields_by_name['plaintext'])
_ENCRYPTDOCSTREAMREQ.fields_by_name['plaintext'].containing_oneof = _ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData']
_DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData'].fields.append(
  _DECRYPTDOCSTREAMREQ.fields_by_name['docID'])
_DECRYPTDOCSTREAMREQ.fields_by_name['docID'].containing_oneof = _DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData']
_DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData'].fields.append(
  _DECRYPTDOCSTREAMREQ.fields_by_name['ciphertext'])
_DECRYPTDOCSTREAMREQ.fields_by_name['ciphertext'].containing_oneof = _DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData']
DESCRIPTOR.message_types_by_name['EncryptDocStreamReq'] = _ENCRYPTDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['EncryptDocStreamResp'] = _ENCRYPTDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['DecryptDocStreamReq'] = _DECRYPTDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['DecryptDocStreamResp'] = _DECRYPTDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['EncryptDocReq'] = _ENCRYPTDOCREQ
DESCRIPTOR.message_types_by_name['EncryptDocResp'] = _ENCRYPTDOCRESP
DESCRIPTOR.message_types_by_name['DecryptDocReq'] = _DECRYPTDOCREQ
DESCRIPTOR.message_types_by_name['DecryptDocResp'] = _DECRYPTDOCRESP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncryptDocStreamReq = _reflection.GeneratedProtocolMessageType('EncryptDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCSTREAMREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocStreamReq)
  })
_sym_db.RegisterMessage(EncryptDocStreamReq)

EncryptDocStreamResp = _reflection.GeneratedProtocolMessageType('EncryptDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCSTREAMRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocStreamResp)
  })
_sym_db.RegisterMessage(EncryptDocStreamResp)

DecryptDocStreamReq = _reflection.GeneratedProtocolMessageType('DecryptDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCSTREAMREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocStreamReq)
  })
_sym_db.RegisterMessage(DecryptDocStreamReq)

DecryptDocStreamResp = _reflection.GeneratedProtocolMessageType('DecryptDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCSTREAMRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocStreamResp)
  })
_sym_db.RegisterMessage(DecryptDocStreamResp)

EncryptDocReq = _reflection.GeneratedProtocolMessageType('EncryptDocReq', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocReq)
  })
_sym_db.RegisterMessage(EncryptDocReq)

EncryptDocResp = _reflection.GeneratedProtocolMessageType('EncryptDocResp', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocResp)
  })
_sym_db.RegisterMessage(EncryptDocResp)

DecryptDocReq = _reflection.GeneratedProtocolMessageType('DecryptDocReq', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocReq)
  })
_sym_db.RegisterMessage(DecryptDocReq)

DecryptDocResp = _reflection.GeneratedProtocolMessageType('DecryptDocResp', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocResp)
  })
_sym_db.RegisterMessage(DecryptDocResp)


DESCRIPTOR._options = None
_ENCRYPTDOCREQ._options = None
_ENCRYPTDOCRESP._options = None
_DECRYPTDOCREQ._options = None
_DECRYPTDOCRESP._options = None
# @@protoc_insertion_point(module_scope)
